@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: compose.c,v 1.22 1998/10/13 20:44:49 roessler Exp $";
+static const char rcsid[]="$Id: compose.c,v 1.25 1998/10/15 20:33:15 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -814,8 +814,21 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	{
 	  if ((i = mutt_check_encoding (buf)) != ENCOTHER)
 	  {
-	    idx[menu->current]->content->encoding = i;
-	    menu->redraw = REDRAW_CURRENT;
+#ifndef PERMIT_DEPRECATED_UUENCODED_MESSAGES
+	    if (i == ENCUUENCODED)
+	    {
+	      mutt_error _("Invalid encoding.");
+	      break;
+	    }
+#else
+	    if(i != ENCUUENCODED ||
+	      mutt_yesorno(_("This encoding is deprecated.  Really use it?"), 0) == M_YES)
+#endif
+	    {
+	      idx[menu->current]->content->encoding = i;
+	      menu->redraw = REDRAW_CURRENT;
+	      mutt_clear_error();
+	    }
 	  }
 	  else
 	    mutt_error _("Invalid encoding.");
