@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: handler.c,v 1.14 1998/10/13 20:45:10 roessler Exp $";
+static const char rcsid[]="$Id: handler.c,v 1.19 1998/10/15 20:33:29 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -85,7 +85,7 @@ void mutt_decode_xbit (STATE *s, BODY *b, int istext)
     char *charset = mutt_get_parameter("charset", b->parameter);
     int is_utf8;
 
-    if((is_utf8 = mutt_is_utf8(charset)))
+    if((is_utf8 = (mutt_is_utf8(charset) && !mutt_is_utf8(Charset))))
       chs = mutt_get_charset(Charset);
     else
       map = mutt_get_translation(charset, Charset);
@@ -141,7 +141,7 @@ void mutt_decode_quoted (STATE *s, BODY *b, int istext)
   
   if(istext)
   {
-    if((is_utf8 = mutt_is_utf8(charset)))
+    if((is_utf8 = (mutt_is_utf8(charset) && !mutt_is_utf8(Charset))))
       chs = mutt_get_charset(Charset);
     else
       map = mutt_get_translation(charset, Charset);
@@ -223,7 +223,7 @@ void mutt_decode_base64 (STATE *s, BODY *b, int istext)
 
   if(istext)
   {
-    if((is_utf8 = mutt_is_utf8(charset)))
+    if((is_utf8 = (mutt_is_utf8(charset) && !mutt_is_utf8(Charset))))
       chs = mutt_get_charset(Charset);
     else
       map = mutt_get_translation(charset, Charset);
@@ -289,6 +289,72 @@ void mutt_decode_base64 (STATE *s, BODY *b, int istext)
   state_reset_prefix(s);
 }
 
+unsigned char decode_byte (char ch)
+{
+  if (ch == 96)
+    return 0;
+  return ch - 32;
+}
+
+void mutt_decode_uuencoded (STATE *s, BODY *b, int istext)
+{
+  char tmps[SHORT_STRING];
+  char linelen, c, l, out;
+  char *pt;
+  CHARSET_MAP *map = NULL;
+  CHARSET *chs = NULL;
+  char *charset = mutt_get_parameter("charset", b->parameter);
+  int is_utf8 = 0;
+  long len = b->length;
+  
+  if(istext && (is_utf8 = (mutt_is_utf8(charset) && !mutt_is_utf8(Charset))))
+    chs = mutt_get_charset(Charset);
+  else
+    map = mutt_get_translation(charset, Charset);
+
+  if(istext)
+    state_set_prefix(s);
+  
+  while(len > 0)
+  {
+    if ((fgets(tmps, sizeof(tmps), s->fpin)) == NULL)
+      return;
+    len -= strlen(tmps);
+    if ((!strncmp (tmps, "begin", 5)) && isspace (tmps[5]))
+      break;
+  }
+  while(len > 0)
+  {
+    if ((fgets(tmps, sizeof(tmps), s->fpin)) == NULL)
+      return;
+    len -= strlen(tmps);
+    if (!strncmp (tmps, "end", 3))
+      break;
+    pt = tmps;
+    linelen = decode_byte (*pt);
+    pt++;
+    for (c = 0; c < linelen;)
+    {
+      for (l = 2; l <= 6; l += 2)
+      {
+	out = decode_byte (*pt) << l;
+	pt++;
+	out |= (decode_byte (*pt) >> (6 - l));
+	state_maybe_utf8_putc(s, out, is_utf8, chs, map);
+	c++;
+	if (c == linelen)
+	  break;
+      }
+      pt++;
+    }
+  }
+  
+  state_reset_prefix(s);
+  if(is_utf8)
+    state_fput_utf8(s, '\0', chs);
+  
+}
+
 /* ----------------------------------------------------------------------------
  * A (not so) minimal implementation of RFC1563.
  */
@@ -892,7 +958,8 @@ void message_handler (BODY *a, STATE *s)
   long off_start;
 
   off_start = ftell (s->fpin);
-  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE)
+  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE || 
+      a->encoding == ENCUUENCODED)
   {
     fstat (fileno (s->fpin), &st);
     b = mutt_new_body ();
@@ -915,7 +982,8 @@ void message_handler (BODY *a, STATE *s)
     mutt_body_handler (b->parts, s);
   }
 
-  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE)
+  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE ||
+      a->encoding == ENCUUENCODED)
     mutt_free_body (&b);
 }
 
@@ -979,7 +1047,8 @@ void multipart_handler (BODY *a, STATE *s)
   struct stat st;
   int count;
 
-  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE)
+  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE ||
+      a->encoding == ENCUUENCODED)
   {
     fstat (fileno (s->fpin), &st);
     b = mutt_new_body ();
@@ -1037,7 +1106,8 @@ void multipart_handler (BODY *a, STATE *s)
     state_putc ('\n', s);
   }
 
-  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE)
+  if (a->encoding == ENCBASE64 || a->encoding == ENCQUOTEDPRINTABLE ||
+      a->encoding == ENCUUENCODED)
     mutt_free_body (&b);
 }
 
@@ -1173,6 +1243,9 @@ void mutt_decode_attachment (BODY *b, STATE *s)
     case ENCBASE64:
       mutt_decode_base64 (s, b, mutt_is_text_type (b->type, b->subtype));
       break;
+    case ENCUUENCODED:
+      mutt_decode_uuencoded (s, b, mutt_is_text_type (b->type, b->subtype));
+      break;
     default:
       mutt_decode_xbit (s, b, mutt_is_text_type (b->type, b->subtype));
       break;
@@ -1286,7 +1359,7 @@ void mutt_body_handler (BODY *b, STATE *s)
 
     /* see if we need to decode this part before processing it */
     if (b->encoding == ENCBASE64 || b->encoding == ENCQUOTEDPRINTABLE ||
-	plaintext)
+	b->encoding == ENCUUENCODED || plaintext)
     {
       int origType = b->type;
       char *savePrefix = NULL;
