@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: main.c,v 1.13 1998/10/13 20:45:28 roessler Exp $";
+static const char rcsid[]="$Id: main.c,v 1.16 1998/10/15 20:33:41 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -33,6 +33,10 @@ static char rcsid[]="$Id: main.c,v 1.13 1998/10/13 20:45:28 roessler Exp $";
 #include <sys/stat.h>
 #include <sys/utsname.h>
 
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif
+
 const char ReachingUs[] = N_("\
 To contact the developers, please mail to <mutt-dev@mutt.org>.\n");
 
@@ -564,7 +568,7 @@ int main (int argc, char **argv)
       tempfile = safe_strdup (buf);
 
       if (draftFile)
-	msg->env = mutt_read_rfc822_header (fin, NULL);
+	msg->env = mutt_read_rfc822_header (fin, NULL, 1);
 
       if (tempfile)
       {
