@@ -1,4 +1,4 @@
-/* $Id: mime.h,v 1.3 1998/10/13 20:45:34 roessler Exp $ */
+/* $Id: mime.h,v 1.4 1998/10/14 22:34:14 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -39,7 +39,8 @@ enum
   ENC8BIT,
   ENCQUOTEDPRINTABLE,
   ENCBASE64,
-  ENCBINARY
+  ENCBINARY,
+  ENCUUENCODED
 };
 
 /* Content-Disposition values */
