@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: sendlib.c,v 1.22 1998/10/13 20:46:11 roessler Exp $";
+static const char rcsid[]="$Id: sendlib.c,v 1.27 1998/10/15 20:34:06 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -315,6 +315,69 @@ static void encode_base64 (FILE * fin, FILE *fout, int istext)
   fputc('\n', fout);
 }
 
+#ifdef PERMIT_DEPRECATED_UUENCODED_MESSAGES
+
+#define UUENC(c) ((c) ? ((c) & 077) + ' ' : '`')
+
+static void encode_uuenc (FILE * fin, FILE * fout)
+{
+  register int ch, linelen;
+  register unsigned char *p;
+  unsigned char line[80];
+
+  while ((linelen = fread(line, 1, 45, fin)))
+  {
+    ch = UUENC(linelen);
+    fputc (ch, fout);
+
+    for (p = line; linelen>0; linelen -= 3, p += 3)
+    {
+      ch = *p >> 2;
+      ch = UUENC(ch);
+      fputc(ch, fout);
+
+      if (linelen>1)
+      {
+	ch = ((*p & 0x3) << 4) | (p[1] >> 4);
+	ch = UUENC(ch);
+	fputc(ch, fout);
+      }
+      else
+      {
+	ch = (*p & 0x3) << 4;
+	ch = UUENC(ch);
+	fputc(ch, fout);
+	break;
+      }
+
+      if (linelen>2)
+      {
+	ch = ((p[1] & 0xf) << 2) | (p[2] >> 6);
+	ch = UUENC(ch);
+	fputc(ch, fout);
+      }
+      else
+      {
+	ch = (p[1] & 0xf) << 2;
+	ch = UUENC(ch);
+	fputc(ch, fout);
+	break;
+      }
+
+      ch = p[2] & 0x3f;
+      ch = UUENC(ch);
+      fputc(ch, fout);
+    }
+
+    fputc('\n', fout);
+  }
+  ch = UUENC('\0');
+  fputc(ch, fout);
+  fputc('\n', fout);
+}
+
+#endif
+
 int mutt_write_mime_header (BODY *a, FILE *f)
 {
   PARAMETER *p;
@@ -399,6 +462,9 @@ int mutt_write_mime_body (BODY *a, FILE *f)
   char *p, boundary[SHORT_STRING];
   FILE *fpin;
   BODY *t;
+#ifdef PERMIT_DEPRECATED_UUENCODED_MESSAGES
+  char *r;
+#endif
 
   if (a->type == TYPEMULTIPART)
   {
@@ -448,6 +514,19 @@ int mutt_write_mime_body (BODY *a, FILE *f)
     encode_quoted (fpin, f, mutt_is_text_type (a->type, a->subtype));
   else if (a->encoding == ENCBASE64)
     encode_base64 (fpin, f, mutt_is_text_type (a->type, a->subtype));
+#ifdef PERMIT_DEPRECATED_UUENCODED_MESSAGES
+  else if (a->encoding == ENCUUENCODED)
+  {
+    /* Strip off the leading path... */
+    if ((r = strrchr (a->filename, '/')))
+      r++;
+    else
+      r = a->filename;
+    fprintf (f, "begin 600 %s\n", r);
+    encode_uuenc (fpin, f);
+    fprintf (f, "end\n");
+  }
+#endif
   else
     mutt_copy_stream (fpin, f);
   fclose (fpin);
@@ -953,7 +1032,8 @@ BODY *mutt_make_message_attach (CONTEXT *ctx, HEADER *hdr, int attach_msg)
 
   body->hdr = mutt_new_header();
   body->hdr->offset = 0;
-  body->hdr->env = mutt_read_rfc822_header(fp, body->hdr);
+  /* we don't need the user headers here */
+  body->hdr->env = mutt_read_rfc822_header(fp, body->hdr, 0);
 #ifdef _PGPPATH
   body->hdr->pgp = pgp;
 #endif /* _PGPPATH */
